@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 - 2010 Vivien Malerba
+ * Copyright (C) 2009 - 2011 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -241,7 +241,7 @@ browser_connection_class_init (BrowserConnectionClass *klass)
 	g_object_class_install_property (object_class, PROP_GDA_CNC,
                                          g_param_spec_object ("gda-connection", NULL, "Connection to use",
                                                               GDA_TYPE_CONNECTION,
-                                                              G_PARAM_READABLE | G_PARAM_WRITABLE |
+                                                              G_PARAM_WRITABLE |
 							      G_PARAM_CONSTRUCT_ONLY));
 
 	object_class->dispose = browser_connection_dispose;
@@ -328,6 +328,7 @@ wrapper_meta_struct_sync (BrowserConnection *bcnc, GError **error)
 	return GINT_TO_POINTER (retval ? 2 : 1);
 }
 
+
 static void
 meta_changed_cb (G_GNUC_UNUSED GdaThreadWrapper *wrapper,
 		 G_GNUC_UNUSED GdaMetaStore *store,
@@ -359,6 +360,20 @@ meta_changed_cb (G_GNUC_UNUSED GdaThreadWrapper *wrapper,
 	}
 }
 
+/**
+ * browser_connection_meta_data_changed
+ * @bcnc: a #BrowserConnection
+ *
+ * Call this function if the meta data has been changed directly (ie. for example after
+ * declaring or undeclaring a foreign key). This call creates a new #GdaMetaStruct internally used.
+ */
+void
+browser_connection_meta_data_changed (BrowserConnection *bcnc)
+{
+	g_return_if_fail (BROWSER_IS_CONNECTION (bcnc));
+	meta_changed_cb (NULL, NULL, NULL, 0, NULL, NULL, bcnc);
+}
+
 static void
 browser_connection_set_property (GObject *object,
 				 guint param_id,
@@ -1867,7 +1882,7 @@ typedef struct {
  * preferences to set the GdaHolder's plugin attribute
  */
 static gboolean
-foreach_ui_plugins_for_params (GdaSqlAnyPart *part, ParamsData *data, GError **error)
+foreach_ui_plugins_for_params (GdaSqlAnyPart *part, ParamsData *data, G_GNUC_UNUSED GError **error)
 {
 	if (part->type != GDA_SQL_ANY_EXPR)
 		return TRUE;
